SQLAlchemy 0.4 Documentation - module sqlalchemy.exceptions

# SQLAlchemy 0.4 Documentation

Multiple Pages | One Page
Version: 0.4 Last Updated: 08/16/07 11:15:18

### module sqlalchemy.exceptions

### class ArgumentError()

Raised for all those conditions where invalid arguments are sent to constructed objects. This error generally corresponds to construction time state errors.

back to section top

### class AssertionError()

Corresponds to internal state being detected in an invalid state.

back to section top

### class CircularDependencyError()

Raised by topological sorts when a circular dependency is detected

back to section top

### class CompileError()

Raised when an error occurs during SQL compilation

back to section top

### class ConcurrentModificationError()

Raised when a concurrent modification condition is detected.

back to section top

### class DBAPIError()

Raised when the execution of a database operation fails.

`DBAPIError` wraps exceptions raised by the DB-API underlying the database operation. Driver-specific implementations of the standard DB-API exception types are wrapped by matching sub-types of SQLAlchemy's `DBAPIError` when possible. DB-API's `Error` type maps to `DBAPIError` in SQLAlchemy, otherwise the names are identical. Note that there is no guarantee that different DB-API implementations will raise the same exception type for any given error condition.

If the error-raising operation occured in the execution of a SQL statement, that statement and its parameters will be available on the exception object in the `statement` and `params` attributes.

The wrapped exception object is available in the `orig` attribute. Its type and properties are DB-API implementation specific.

def __init__(self, statement, params, orig)

Construct a new `DBAPIError`.

def __new__(cls, statement, params, orig, *args, **kw)
back to section top

### class DataError()

Wraps a DB-API DataError.

back to section top

### class DatabaseError()

Wraps a DB-API DatabaseError.

back to section top

### class DisconnectionError()

Raised within `Pool` when a disconnect is detected on a raw DBAPI connection.

back to section top

### class FlushError()

Raised when an invalid condition is detected upon a `flush()`.

back to section top

### class IntegrityError()

Wraps a DB-API IntegrityError.

back to section top

### class InterfaceError()

Wraps a DB-API InterfaceError.

back to section top

### class InvalidRequestError()

SQLAlchemy was asked to do something it can't do, return nonexistent data, etc.

This error generally corresponds to runtime state errors.

back to section top

### class NoSuchColumnError()

Raised by `RowProxy` when a nonexistent column is requested from a row.

back to section top

### class NoSuchTableError()

SQLAlchemy was asked to load a table's definition from the database, but the table doesn't exist.

back to section top

### class NotSupportedError()

Wraps a DB-API NotSupportedError.

back to section top

### class OperationalError()

Wraps a DB-API OperationalError.

back to section top

### class ProgrammingError()

Wraps a DB-API ProgrammingError.

back to section top

### class SQLAlchemyError()

Generic error class.

back to section top

### class TimeoutError()

Raised when a connection pool times out on getting a connection.

back to section top